==> digikam-4.5.0.tar.bz2: digikam-4.5.0/extra/kipi-plugins/photolayoutseditor/plugin/kipiplugin_photolayoutseditor.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Photo Layouts Editor
Name=Photo Layouts Editor
Name[bs]=Uređivač foto rasporeda
Name[ca]=Editor de presentacions de foto
Name[ca@valencia]=Editor de presentacions de foto
Name[cs]=Editor rozvržení snímků
Name[da]=Editor til fotolayout
Name[de]=Fotolayout-Editor
Name[el]=Επεξεργαστής διατάξεων φωτογραφιών
Name[en_GB]=Photo Layouts Editor
Name[es]=Editor de formatos de fotos
Name[et]=Fotode paigutusredaktor
Name[fr]=Éditeur de dispositions de photos
Name[gl]=Editor das disposicións das fotos
Name[hu]=Fényképelrendezés szerkesztő
Name[is]=Ljósmyndauppsetningarforrit
Name[it]=Editor di impaginazioni di foto
Name[km]=កម្មវិធី​កែសម្រួល​ប្លង់​រូបថត
Name[nb]=Fotoutleggsredigerer
Name[nl]=Foto-indelingbewerker
Name[pl]=Edytor układów zdjęć
Name[pt]=Editor de Formatos de Fotografias
Name[pt_BR]=Editor de formatos de fotos
Name[sk]=Editor rozložení fotiek
Name[sl]=Urejevalnik razporedov slik
Name[sv]=Fotolayouteditor
Name[tr]=Fotoğraf Yerleşim Düzenleyici
Name[ug]=Photo Layouts Editor
Name[uk]=Редактор компонування фотографій
Name[x-test]=xxPhoto Layouts Editorxx
Name[zh_TW]=相片佈局編輯器
Comment=A tool to make photo layouts
Comment[ca]=Una eina per crear presentacions de les fotos
Comment[cs]=Nástroj pro vytváření rozvržení snímků
Comment[da]=Et værktøj til at lave fotolayout
Comment[de]=Ein Werkzeug, um Fotolayouts zu erstellen
Comment[el]=Εργαλείο δημιουργίας διατάξεων φωτογραφιών
Comment[en_GB]=A tool to make photo layouts
Comment[es]=Una herramienta para hacer distribuciones de fotografías
Comment[it]=Uno strumento impaginare le foto
Comment[nl]=Een hulpmiddel voor het maken van foto-indelingen
Comment[pl]=Narzędzie do tworzenia układów zdjęć
Comment[pt]=Uma ferramenta para criar disposições de fotografias
Comment[pt_BR]=Uma ferramenta para criar leiautes de fotos
Comment[sk]=Nástroj na tvorbu rozložení fotiek
Comment[sl]=Orodje za urejanje razporedov slik
Comment[sv]=Ett verktyg för skapa fotolayouter
Comment[uk]=Інструмент для створення фотокомпозицій
Comment[x-test]=xxA tool to make photo layoutsxx
Icon=photolayoutseditor
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_photolayoutseditor
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Łukasz Spas, lukasz dot spas at gmail dot com

==> digikam-4.7.0.tar.bz2: digikam-4.7.0/extra/kipi-plugins/photolayoutseditor/plugin/kipiplugin_photolayoutseditor.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Photo Layouts Editor
Name=Photo Layouts Editor
Name[bs]=Uređivač foto rasporeda
Name[ca]=Editor de presentacions de foto
Name[ca@valencia]=Editor de presentacions de foto
Name[cs]=Editor rozvržení snímků
Name[da]=Editor til fotolayout
Name[de]=Fotolayout-Editor
Name[el]=Επεξεργαστής διατάξεων φωτογραφιών
Name[en_GB]=Photo Layouts Editor
Name[es]=Editor de formatos de fotos
Name[et]=Fotode paigutusredaktor
Name[fr]=Éditeur de dispositions de photos
Name[gl]=Editor das disposicións das fotos
Name[hu]=Fényképelrendezés szerkesztő
Name[is]=Ljósmyndauppsetningarforrit
Name[it]=Editor di impaginazioni di foto
Name[km]=កម្មវិធី​កែសម្រួល​ប្លង់​រូបថត
Name[nb]=Fotoutleggsredigerer
Name[nl]=Foto-indelingbewerker
Name[pl]=Edytor układów zdjęć
Name[pt]=Editor de Formatos de Fotografias
Name[pt_BR]=Editor de formatos de fotos
Name[sk]=Editor rozložení fotiek
Name[sl]=Urejevalnik razporedov slik
Name[sv]=Fotolayouteditor
Name[tr]=Fotoğraf Yerleşim Düzenleyici
Name[ug]=Photo Layouts Editor
Name[uk]=Редактор компонування фотографій
Name[x-test]=xxPhoto Layouts Editorxx
Name[zh_TW]=相片佈局編輯器
Comment=A tool to make photo layouts
Comment[ca]=Una eina per crear presentacions de les fotos
Comment[cs]=Nástroj pro vytváření rozvržení snímků
Comment[da]=Et værktøj til at lave fotolayout
Comment[de]=Ein Werkzeug, um Fotolayouts zu erstellen
Comment[el]=Εργαλείο δημιουργίας διατάξεων φωτογραφιών
Comment[en_GB]=A tool to make photo layouts
Comment[es]=Una herramienta para hacer distribuciones de fotografías
Comment[is]=Verkfæri til að setja upp myndir
Comment[it]=Uno strumento impaginare le foto
Comment[nl]=Een hulpmiddel voor het maken van foto-indelingen
Comment[pl]=Narzędzie do tworzenia układów zdjęć
Comment[pt]=Uma ferramenta para criar disposições de fotografias
Comment[pt_BR]=Ferramenta para criar leiautes de fotos
Comment[sk]=Nástroj na tvorbu rozložení fotiek
Comment[sl]=Orodje za urejanje razporedov slik
Comment[sv]=Ett verktyg för skapa fotolayouter
Comment[uk]=Інструмент для створення фотокомпозицій
Comment[x-test]=xxA tool to make photo layoutsxx
Icon=photolayoutseditor
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_photolayoutseditor
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Łukasz Spas, lukasz dot spas at gmail dot com
